@@ -31,7 +31,6 @@ class BqRemoteParser:
     @staticmethod
     def parse(kensu, client: bq.Client, query: str, db_metadata, table_id_to_bqtable) -> GenericComputedInMemDs:
         ## POST REQUEST to /lineage-and-stats-criterions
-        query = query.replace("PARSE_DATETIME", "to_timestamp")
         req = {"sql": query, "metadata": db_metadata}
         url = kensu.sql_util_url
         logger.debug("sending request to SQL parsing service url={} request={}".format(url, str(req)))
@@ -91,7 +90,7 @@ class BqRemoteParser:
                         input_filters=stats_filters)
                 except Exception as e:
                     stats_values = None
-                    logger.debug(f"Unable to compute the stats: {e}")
+                    logger.warning(f"Unable to compute the stats: {e}")
 
             logger.debug(
                 f'table_id {table_id} (table.ref={bg_table_ref}, ds_path: {ds_path}) got input_filters: {stats_filters} & stat_aggs:{str(stats_aggs)}')
